@@ -3,21 +3,13 @@
 udocker unit tests: ExecutionEngineCommon
 """
 
-import os
-import sys
-
-new_path = []
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
-new_path.extend(sys.path)
-sys.path = new_path
-
 from unittest import TestCase, main
 from unittest.mock import Mock, patch
 from udocker.engine.base import ExecutionEngineCommon
 from udocker.utils.uenv import Uenv
-from config import Config
+from udocker.config import Config
 import collections
+
 collections.Callable = collections.abc.Callable
 
 
