@@ -4,19 +4,12 @@ udocker unit tests: FakechrootEngine
 """
 
 import os
-import sys
-
-new_path = []
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
-new_path.extend(sys.path)
-sys.path = new_path
-
 from unittest import TestCase, main
 from unittest.mock import patch, Mock
-from config import Config
+from udocker.config import Config
 from udocker.engine.fakechroot import FakechrootEngine
 import collections
+
 collections.Callable = collections.abc.Callable
 
 
