@@ -3,19 +3,11 @@
 udocker unit tests: OciLocalFileAPI
 """
 
-import os
-import sys
-
-new_path = []
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
-new_path.extend(sys.path)
-sys.path = new_path
-
 from unittest import TestCase, main
 from unittest.mock import patch, Mock
 from udocker.oci import OciLocalFileAPI
 import collections
+
 collections.Callable = collections.abc.Callable
 
 
