@@ -3,22 +3,13 @@
 udocker unit tests: RuncEngine
 """
 
-import os
-import sys
-
-new_path = []
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
-new_path.extend(sys.path)
-sys.path = new_path
-
 from unittest import TestCase, main
 from unittest.mock import Mock, patch, mock_open
-from config import Config
+from udocker.config import Config
 from udocker.engine.runc import RuncEngine
 import collections
-collections.Callable = collections.abc.Callable
 
+collections.Callable = collections.abc.Callable
 BUILTINS = "builtins"
 BOPEN = BUILTINS + '.open'
 
