@@ -10,10 +10,10 @@ import json
 from udocker.config import Config
 from udocker.msg import Msg
 from udocker.commonlocalfile import CommonLocalFileApi
+from udocker.helper.unique import Unique
 from udocker.utils.fileutil import FileUtil
 from udocker.utils.curl import GetURL
 from udocker.utils.chksum import ChkSUM
-from udocker.helper.unique import Unique
 
 
 class DockerIoAPI(object):
@@ -64,8 +64,8 @@ class DockerIoAPI(object):
             kwargs["FOLLOW"] = 3
         kwargs["RETRY"] -= 1
         (hdr, buf) = self.curl.get(*args, **kwargs)
-        Msg().out("Info: header: %s" % (hdr.data), l=Msg.DBG)
-        Msg().out("Info: buffer: %s" % (buf.getvalue()), l=Msg.DBG)
+        Msg().out("Debug: header: %s" % hdr.data, l=Msg.DBG)
+        Msg().out("Debug: buffer: %s" % buf.getvalue(), l=Msg.DBG)
         status_code = self.curl.get_status_code(hdr.data["X-ND-HTTPSTATUS"])
         if status_code == 200:
             return (hdr, buf)
@@ -86,7 +86,7 @@ class DockerIoAPI(object):
         elif status_code == 401:
             if "www-authenticate" in hdr.data:
                 www_authenticate = hdr.data["www-authenticate"]
-                if not "realm" in www_authenticate:
+                if "realm" not in www_authenticate:
                     return (hdr, buf)
                 if 'error="insufficient_scope"' in www_authenticate:
                     return (hdr, buf)
@@ -139,7 +139,7 @@ class DockerIoAPI(object):
 
     def _split_fields(self, buf):
         """Split  fields, used in the web authentication"""
-        all_fields = dict()
+        all_fields = {}
         for field in buf.split(','):
             pair = field.split('=', 1)
             if len(pair) == 2:
@@ -174,12 +174,12 @@ class DockerIoAPI(object):
     def get_v1_repo(self, imagerepo):
         """Get list of images in a repo from Docker Hub"""
         url = self.index_url + "/v1/repositories/" + imagerepo + "/images"
-        Msg().out("Info: repo url", url, l=Msg.DBG)
+        Msg().out("Debug: repo url", url, l=Msg.DBG)
         (hdr, buf) = self._get_url(url, header=["X-Docker-Token: true"])
         try:
             self.v1_auth_header = "Authorization: Token " + \
                 hdr.data["x-docker-token"]
-            return hdr.data, json.loads(buf.getvalue())
+            return hdr.data, json.loads(buf.getvalue().decode())
         except (IOError, OSError, AttributeError,
                 ValueError, TypeError, KeyError):
             self.v1_auth_header = ""
@@ -199,43 +199,43 @@ class DockerIoAPI(object):
         except KeyError:
             endpoint = self.index_url
         url = endpoint + "/v1/repositories/" + imagerepo + "/tags"
-        Msg().out("Info: tags url", url, l=Msg.DBG)
+        Msg().out("Debug: tags url", url, l=Msg.DBG)
         (dummy, buf) = self._get_url(url)
         tags = []
         try:
             if tags_only:
-                for tag in json.loads(buf.getvalue()):
+                for tag in json.loads(buf.getvalue().decode()):
                     tags.append(tag["name"])
                 return tags
 
-            return json.loads(buf.getvalue())
+            return json.loads(buf.getvalue().decode())
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             return []
 
     def get_v1_image_tag(self, endpoint, imagerepo, tag):
         """Get list of tags in a repo from Docker Hub"""
         url = endpoint + "/v1/repositories/" + imagerepo + "/tags/" + tag
-        Msg().out("Info: tags url", url, l=Msg.DBG)
+        Msg().out("Debug: tags url", url, l=Msg.DBG)
         (hdr, buf) = self._get_url(url)
         try:
-            return (hdr.data, json.loads(buf.getvalue()))
+            return (hdr.data, json.loads(buf.getvalue()).decode())
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             return (hdr.data, [])
 
     def get_v1_image_ancestry(self, endpoint, image_id):
         """Get the ancestry which is an ordered list of layers"""
         url = endpoint + "/v1/images/" + image_id + "/ancestry"
-        Msg().out("Info: ancestry url", url, l=Msg.DBG)
+        Msg().out("Debug: ancestry url", url, l=Msg.DBG)
         (hdr, buf) = self._get_url(url)
         try:
-            return (hdr.data, json.loads(buf.getvalue()))
+            return (hdr.data, json.loads(buf.getvalue().decode()))
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             return (hdr.data, [])
 
     def get_v1_image_json(self, endpoint, layer_id):
         """Get the JSON metadata for a specific layer"""
         url = endpoint + "/v1/images/" + layer_id + "/json"
-        Msg().out("Info: json url", url, l=Msg.DBG)
+        Msg().out("Debug: json url", url, l=Msg.DBG)
         filename = self.localrepo.layersdir + '/' + layer_id + ".json"
         if self._get_file(url, filename, 0):
             self.localrepo.add_image_layer(filename)
@@ -245,7 +245,7 @@ class DockerIoAPI(object):
     def get_v1_image_layer(self, endpoint, layer_id):
         """Get a specific layer data file (layer files are tarballs)"""
         url = endpoint + "/v1/images/" + layer_id + "/layer"
-        Msg().out("Info: layer url", url, l=Msg.DBG)
+        Msg().out("Debug: layer url", url, l=Msg.DBG)
         filename = self.localrepo.layersdir + '/' + layer_id + ".layer"
         if self._get_file(url, filename, 3):
             self.localrepo.add_image_layer(filename)
@@ -276,18 +276,15 @@ class DockerIoAPI(object):
             auth_fields = self._split_fields(auth_data)
             if "realm" in auth_fields:
                 auth_url = auth_fields["realm"] + '?'
-                for field in auth_fields:
+                for (field, value) in auth_fields.items():
                     if field != "realm":
-                        auth_url += field + '=' + auth_fields[field] + '&'
+                        auth_url += field + '=' + value + '&'
                 header = []
                 if self.v2_auth_token:
-                    header = ["Authorization: Basic %s" % (self.v2_auth_token)]
+                    header = ["Authorization: Basic %s" % self.v2_auth_token]
                 (dummy, auth_buf) = self._get_url(auth_url, header=header,
                                                   RETRY=retry)
-                if sys.version_info[0] >= 3:
-                    token_buf = auth_buf.getvalue().decode()
-                else:
-                    token_buf = auth_buf.getvalue()
+                token_buf = auth_buf.getvalue().decode()
                 if token_buf and "token" in token_buf:
                     try:
                         auth_token = json.loads(token_buf)
@@ -299,7 +296,7 @@ class DockerIoAPI(object):
                     self.v2_auth_header = auth_header
         # PR #126
         elif 'BASIC' in bearer or 'Basic' in bearer:
-            auth_header = "Authorization: Basic %s" %(self.v2_auth_token)
+            auth_header = "Authorization: Basic %s" % self.v2_auth_token
             self.v2_auth_header = auth_header
         return auth_header
 
@@ -308,11 +305,11 @@ class DockerIoAPI(object):
         if not (username and password):
             return ""
         try:
-            self.v2_auth_token = \
-                base64.b64encode(("%s:%s" % \
-                    (username, password)).encode("utf-8")).decode("ascii")
+            userpass = ("%s:%s" % (username, password)).encode("utf-8")
+            self.v2_auth_token = base64.b64encode(userpass).decode("ascii")
         except (KeyError, AttributeError, TypeError, ValueError, NameError):
             self.v2_auth_token = ""
+
         return self.v2_auth_token
 
     def set_v2_login_token(self, v2_auth_token):
@@ -346,16 +343,16 @@ class DockerIoAPI(object):
     def get_v2_image_tags(self, imagerepo, tags_only=False):
         """Get list of tags in a repo from Docker Hub"""
         url = self.registry_url + "/v2/" + imagerepo + "/tags/list"
-        Msg().out("Info: tags url", url, l=Msg.DBG)
+        Msg().out("Debug: tags url", url, l=Msg.DBG)
         (dummy, buf) = self._get_url(url)
         tags = []
         try:
             if tags_only:
-                for tag in json.loads(buf.getvalue())["tags"]:
+                for tag in json.loads(buf.getvalue().decode())["tags"]:
                     tags.append(tag)
                 return tags
 
-            return json.loads(buf.getvalue())
+            return json.loads(buf.getvalue().decode())
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             return []
 
@@ -365,10 +362,10 @@ class DockerIoAPI(object):
         """
         url = self.registry_url + "/v2/" + imagerepo + \
             "/manifests/" + tag
-        Msg().out("Info: manifest url", url, l=Msg.DBG)
+        Msg().out("Debug: manifest url", url, l=Msg.DBG)
         (hdr, buf) = self._get_url(url)
         try:
-            return (hdr.data, json.loads(buf.getvalue()))
+            return (hdr.data, json.loads(buf.getvalue().decode()))
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             return (hdr.data, [])
 
@@ -376,7 +373,7 @@ class DockerIoAPI(object):
         """Get one image layer data file (tarball)"""
         url = self.registry_url + "/v2/" + imagerepo + \
             "/blobs/" + layer_id
-        Msg().out("Info: layer url", url, l=Msg.DBG)
+        Msg().out("Debug: layer url", url, l=Msg.DBG)
         filename = self.localrepo.layersdir + '/' + layer_id
         if self._get_file(url, filename, 3):
             self.localrepo.add_image_layer(filename)
@@ -416,7 +413,7 @@ class DockerIoAPI(object):
                 Msg().err("Error: setting localrepo v2 tag and version")
                 return []
             self.localrepo.save_json("manifest", manifest)
-            Msg().out("Info: v2 layers: %s" % (imagerepo), l=Msg.DBG)
+            Msg().out("Debug: v2 layers: %s" % (imagerepo), l=Msg.DBG)
             if "fsLayers" in manifest:
                 files = self.get_v2_layers_all(imagerepo,
                                                manifest["fsLayers"])
@@ -459,7 +456,7 @@ class DockerIoAPI(object):
 
     def get_v1(self, imagerepo, tag):
         """Pull container with v1 API"""
-        Msg().out("Info: v1 image id: %s" % (imagerepo), l=Msg.DBG)
+        Msg().out("Debug: v1 image id: %s" % (imagerepo), l=Msg.DBG)
         (hdr_data, images_array) = self.get_v1_repo(imagerepo)
         status = self.curl.get_status_code(hdr_data["X-ND-HTTPSTATUS"])
         if status == 401 or not images_array:
@@ -483,19 +480,18 @@ class DockerIoAPI(object):
                 self.localrepo.set_version("v1")):
             Msg().err("Error: setting localrepo v1 tag and version")
             return []
-        Msg().out("Info: v1 ancestry", image_id, l=Msg.DBG)
+        Msg().out("Debug: v1 ancestry", image_id, l=Msg.DBG)
         (dummy, ancestry) = self.get_v1_image_ancestry(endpoint, image_id)
         if not ancestry:
             Msg().err("Error: ancestry not found")
             return []
         self.localrepo.save_json("ancestry", ancestry)
-        Msg().out("Info: v1 layers", image_id, l=Msg.DBG)
+        Msg().out("Debug: v1 layers", image_id, l=Msg.DBG)
         files = self.get_v1_layers_all(endpoint, ancestry)
         return files
 
     def _parse_imagerepo(self, imagerepo):
         """Parse imagerepo to extract registry"""
-        remoterepo = imagerepo
         registry = ""
         registry_url = ""
         index_url = ""
@@ -503,8 +499,8 @@ class DockerIoAPI(object):
         if '.' in components[0] and len(components) >= 2:
             registry = components[0]
             del components[0]
-        elif ('.' not in components[0] and
-              components[0] != "library" and len(components) == 1):
+        if ('.' not in components[0] and
+                components[0] != "library" and len(components) == 1):
             components.insert(0, "library")
         remoterepo = '/'.join(components)
         if registry:
@@ -524,8 +520,7 @@ class DockerIoAPI(object):
 
     def get(self, imagerepo, tag):
         """Pull a docker image from a v2 registry or v1 index"""
-        Msg().out("Info: get imagerepo: %s tag: %s" % (imagerepo, tag),
-                  l=Msg.DBG)
+        Msg().out("Debug: get imagerepo: %s tag: %s" % (imagerepo, tag), l=Msg.DBG)
         (imagerepo, remoterepo) = self._parse_imagerepo(imagerepo)
         if self.localrepo.cd_imagerepo(imagerepo, tag):
             new_repo = False
@@ -542,7 +537,7 @@ class DockerIoAPI(object):
 
     def get_tags(self, imagerepo):
         """List tags from a v2 or v1 repositories"""
-        Msg().out("Info: get tags", imagerepo, l=Msg.DBG)
+        Msg().out("Debug: get tags", imagerepo, l=Msg.DBG)
         (dummy, remoterepo) = self._parse_imagerepo(imagerepo)
         if self.is_v2():
             return self.get_v2_image_tags(remoterepo, True)  # try v2
@@ -563,7 +558,7 @@ class DockerIoAPI(object):
         url += "&page=%s" % str(self.search_page)
         (dummy, buf) = self._get_url(url)
         try:
-            repo_list = json.loads(buf.getvalue())
+            repo_list = json.loads(buf.getvalue().decode())
             if repo_list["page"] == repo_list["num_pages"]:
                 self.search_ended = True
             return repo_list
@@ -577,16 +572,11 @@ class DockerIoAPI(object):
         if not expression:
             expression = '*'
         if expression and official is None:
-            url = url + \
-                    "/v2/search/repositories?query=%s" % (expression)
+            url = url + "/v2/search/repositories?query=%s" % (expression)
         elif expression and official is True:
-            url = url + \
-                    "/v2/search/repositories?query=%s&is_official=%s" \
-                    % (expression, "true")
+            url = url + "/v2/search/repositories?query=%s&is_official=%s" % (expression, "true")
         elif expression and official is False:
-            url = url + \
-                    "/v2/search/repositories?query=%s&is_official=%s" \
-                    % (expression, "false")
+            url = url + "/v2/search/repositories?query=%s&is_official=%s" % (expression, "false")
         else:
             return []
         url += "&page_size=%d" % (lines)
@@ -594,7 +584,7 @@ class DockerIoAPI(object):
             url += "&page=%d" % (self.search_page)
         (dummy, buf) = self._get_url(url)
         try:
-            repo_list = json.loads(buf.getvalue())
+            repo_list = json.loads(buf.getvalue().decode())
             if repo_list["count"] == self.search_page:
                 self.search_ended = True
             return repo_list
@@ -628,8 +618,8 @@ class DockerLocalFileAPI(CommonLocalFileApi):
     def _load_structure(self, tmp_imagedir):
         """Load the structure of a Docker image"""
         structure = {}
-        structure["repolayers"] = dict()
-        structure["repoconfigs"] = dict()
+        structure["repolayers"] = {}
+        structure["repoconfigs"] = {}
         for fname in os.listdir(tmp_imagedir):
             f_path = tmp_imagedir + '/' + fname
             if fname == "repositories":
@@ -639,14 +629,12 @@ class DockerLocalFileAPI(CommonLocalFileApi):
                 structure["manifest"] = \
                         self.localrepo.load_json(f_path)
             elif len(fname) >= 69 and fname.endswith(".json"):
-                structure["repoconfigs"][fname] = dict()
-                structure["repoconfigs"][fname]["json"] = \
-                        self.localrepo.load_json(f_path)
-                structure["repoconfigs"][fname]["json_f"] = \
-                        f_path
+                structure["repoconfigs"][fname] = {}
+                structure["repoconfigs"][fname]["json"] = self.localrepo.load_json(f_path)
+                structure["repoconfigs"][fname]["json_f"] = f_path
             elif len(fname) >= 64 and FileUtil(f_path).isdir():
                 layer_id = fname
-                structure["repolayers"][layer_id] = dict()
+                structure["repolayers"][layer_id] = {}
                 for layer_f in os.listdir(f_path):
                     layer_f_path = f_path + '/' + layer_f
                     if layer_f == "VERSION":
@@ -655,13 +643,11 @@ class DockerLocalFileAPI(CommonLocalFileApi):
                     elif layer_f == "json":
                         structure["repolayers"][layer_id]["json"] = \
                                 self.localrepo.load_json(layer_f_path)
-                        structure["repolayers"][layer_id]["json_f"] = \
-                                layer_f_path
+                        structure["repolayers"][layer_id]["json_f"] = layer_f_path
                     elif "layer" in layer_f:
-                        structure["repolayers"][layer_id]["layer_f"] = \
-                                layer_f_path
+                        structure["repolayers"][layer_id]["layer_f"] = layer_f_path
                     else:
-                        Msg().out("Info: warning: unkwnon file in layer:",
+                        Msg().out("Info: warning: unknown file in layer:",
                                   f_path, l=Msg.WAR)
         return structure
 
@@ -713,7 +699,7 @@ class DockerLocalFileAPI(CommonLocalFileApi):
                 if imagetag in repotag["RepoTags"]:
                     layers = []
                     for layer_file in repotag["Layers"]:
-                        #layers.append(layer_file.replace("/layer.tar", ""))
+                        # layers.append(layer_file.replace("/layer.tar", ""))
                         layers.append(layer_file)
                     layers.reverse()
                     return (repotag["Config"], layers)
@@ -722,10 +708,12 @@ class DockerLocalFileAPI(CommonLocalFileApi):
     def _load_image_step2(self, structure, imagerepo, tag):
         """Load a container image into a repository mimic docker load"""
         imagetag = imagerepo + ':' + tag
-        (json_config_file, layers) = \
-                self._get_from_manifest(structure, imagetag)
+        (json_config_file, layers) = self._get_from_manifest(structure, imagetag)
+        Msg().out("Debug: json config file ->", json_config_file, l=Msg.DBG)
         if json_config_file:
             layer_id = json_config_file.replace(".json", "")
+            Msg().out("Debug: layer_id ->", layer_id, l=Msg.DBG)
+            Msg().out("Debug: structure ->", structure, l=Msg.DBG)
             json_file = structure["repoconfigs"][json_config_file]["json_f"]
             self._move_layer_to_v1repo(json_file, layer_id, "container.json")
         top_layer_id = self._find_top_layer_id(structure)
@@ -738,8 +726,7 @@ class DockerLocalFileAPI(CommonLocalFileApi):
             for layer_item in ("json_f", "layer_f"):
                 filename = str(structure["repolayers"][layer_id][layer_item])
                 if not self._move_layer_to_v1repo(filename, layer_id):
-                    Msg().err("Error: copying %s file %s"
-                              % (layer_item[:-2], filename), l=Msg.VER)
+                    Msg().err("Error: copying %s file %s" % (layer_item[:-2], filename), l=Msg.VER)
                     return []
         self.localrepo.save_json("ancestry", layers)
         if self._imagerepo:
@@ -789,12 +776,12 @@ class DockerLocalFileAPI(CommonLocalFileApi):
             return False
         config_layer_file = str(ChkSUM().sha256(json_file)) + ".json"
         FileUtil(json_file).rename(tmp_imagedir + '/' + config_layer_file)
-        manifest_item = dict()
+        manifest_item = {}
         manifest_item["Config"] = config_layer_file
         manifest_item["RepoTags"] = [imagerepo + ':' + tag, ]
         manifest_item["Layers"] = []
         if imagerepo not in structure["repositories"]:
-            structure["repositories"][imagerepo] = dict()
+            structure["repositories"][imagerepo] = {}
         parent_layer_id = ""
         for layer_f in layer_files:
             try:
@@ -832,9 +819,9 @@ class DockerLocalFileAPI(CommonLocalFileApi):
             os.makedirs(tmp_imagedir)
         except (IOError, OSError):
             return False
-        structure = dict()
+        structure = {}
         structure["manifest"] = []
-        structure["repositories"] = dict()
+        structure["repositories"] = {}
         status = False
         for (imagerepo, tag) in imagetag_list:
             status = self._save_image(imagerepo, tag, structure, tmp_imagedir)
