@@ -4,8 +4,8 @@
 import os
 import json
 
-from udocker.utils.fileutil import FileUtil
 from udocker.helper.hostinfo import HostInfo
+from udocker.utils.fileutil import FileUtil
 
 
 class KeyStore(object):
@@ -22,17 +22,17 @@ class KeyStore(object):
         """Verify the keystore file and directory"""
         keystore_uid = FileUtil(self.keystore_file).uid()
         if keystore_uid not in (-1, HostInfo.uid):
-            raise IOError(f"not owner of keystore: {self.keystore_file}")
+            raise IOError("not owner of keystore: %s" % self.keystore_file)
         keystore_dir = os.path.dirname(self.keystore_file)
         if FileUtil(keystore_dir).uid() != HostInfo.uid:
-            raise IOError(f"keystore dir not found or not owner: {keystore_dir}")
+            raise IOError("keystore dir not found or not owner: %s" % keystore_dir)
         if (keystore_uid != -1 and (os.stat(self.keystore_file).st_mode & 0o077)):
-            raise IOError(f"keystore is accessible to group or others: {self.keystore_file}")
+            raise IOError("keystore is accessible to group or others: %s" % self.keystore_file)
 
     def _read_all(self):
         """Read all credentials from file"""
         try:
-            with open(self.keystore_file, "r", encoding='utf-8') as filep:
+            with open(self.keystore_file, "r") as filep:
                 return json.load(filep)
         except (IOError, OSError, ValueError):
             return {}
@@ -57,7 +57,7 @@ class KeyStore(object):
         oldmask = None
         try:
             oldmask = os.umask(0o77)
-            with open(self.keystore_file, "w", encoding='utf-8') as filep:
+            with open(self.keystore_file, "w") as filep:
                 json.dump(auths, filep)
             os.umask(oldmask)
         except (IOError, OSError):
