@@ -3,11 +3,11 @@
 
 import os
 import sys
-from msg import Msg
-from cmdparser import CmdParser
-from config import Config
-from container.localrepo import LocalRepository
-from cli import UdockerCLI
+from udocker.msg import Msg
+from udocker.cmdparser import CmdParser
+from udocker.config import Config
+from udocker.container.localrepo import LocalRepository
+from udocker.cli import UdockerCLI
 
 
 class UMain(object):
