@@ -6,7 +6,7 @@ import sys
 import stat
 import re
 
-from udocker import is_genstr
+from udocker.genstr import is_genstr
 from udocker.msg import Msg
 from udocker.config import Config
 from udocker.helper.unique import Unique
@@ -29,17 +29,23 @@ class FileUtil(object):
             self.filename = "-"
             self.basename = "-"
             return
+
         try:
             self.filename = os.path.abspath(filename)
             self.basename = os.path.basename(self.filename)
         except (AttributeError, TypeError):
             self.filename = filename
             self.basename = filename
+
         self._register_prefix(self._tmpdir)
 
     def _register_prefix(self, prefix):
         """Register directory prefixes where remove() is allowed"""
-        prefix = os.path.realpath(prefix)
+        if os.path.islink(prefix):
+            prefix = os.path.realpath(os.path.dirname(prefix)) + "/" + os.path.basename(prefix)
+        else:
+            prefix = os.path.realpath(prefix)
+
         if prefix not in FileUtil.safe_prefixes:
             filename = prefix
             if os.path.isdir(filename) and not filename.endswith('/'):
@@ -60,6 +66,7 @@ class FileUtil(object):
                 old_umask = os.umask(new_umask)
             except (TypeError, ValueError):
                 return False
+
             if FileUtil.orig_umask is None:
                 FileUtil.orig_umask = old_umask
         else:
@@ -67,13 +74,13 @@ class FileUtil(object):
                 os.umask(FileUtil.orig_umask)
             except (TypeError, ValueError):
                 return False
+
         return True
 
     def mktmp(self):
         """Generate a temporary filename"""
         while True:
-            tmp_file = self._tmpdir + '/' + \
-                Unique().filename(self.basename)
+            tmp_file = self._tmpdir + '/' + Unique().filename(self.basename)
             if not os.path.exists(tmp_file):
                 FileUtil.tmptrash[tmp_file] = True
                 self.filename = tmp_file
@@ -85,6 +92,7 @@ class FileUtil(object):
             os.makedirs(self.filename)
         except (OSError, IOError, AttributeError):
             return False
+
         return True
 
     def rmdir(self):
@@ -93,6 +101,7 @@ class FileUtil(object):
             os.rmdir(self.filename)
         except (OSError, IOError, AttributeError):
             return False
+
         return True
 
     def mktmpdir(self):
@@ -100,6 +109,7 @@ class FileUtil(object):
         dirname = self.mktmp()
         if FileUtil(dirname).mkdir():
             return dirname
+
         return None
 
     def uid(self):
@@ -109,16 +119,23 @@ class FileUtil(object):
         except (IOError, OSError):
             return -1
 
-    def _is_safe_prefix(self, filename):
+    def _is_safe_prefix(self, fname):
         """Check if file prefix falls under valid prefixes"""
-        filename = os.path.realpath(filename)
-        if os.path.isdir(filename):
-            filename += '/'
+        if os.path.islink(fname):
+            fname = os.path.realpath(os.path.dirname(fname)) + "/" + os.path.basename(fname)
+        else:
+            fname = os.path.realpath(fname)
+
+        if os.path.isdir(fname):
+            fname += '/'
+
         for safe_prefix in FileUtil.safe_prefixes:
-            if filename.startswith(safe_prefix):
+            if fname.startswith(safe_prefix):
                 return True
-            if filename.startswith(os.path.realpath(safe_prefix)):
+
+            if fname.startswith(os.path.realpath(safe_prefix)):
                 return True
+
         return False
 
     def chown(self, uid=0, gid=0, recursive=False):
@@ -130,8 +147,10 @@ class FileUtil(object):
                         os.lchown(dir_path + '/' + f_name, uid, gid)
             else:
                 os.lchown(self.filename, uid, gid)
+
         except OSError:
             return False
+
         return True
 
     def rchown(self, uid=0, gid=0):
@@ -153,9 +172,9 @@ class FileUtil(object):
             elif filemode:
                 mode = (stat.S_IMODE(filestat) & mask) | filemode
                 os.chmod(filename, mode)
+
         except OSError:
             Msg().err("Error: changing permissions of:", filename, l=Msg.VER)
-            raise OSError
 
     def chmod(self, filemode=0o600, dirmode=0o700, mask=0o755, recursive=False):
         """chmod directory recursively"""
@@ -169,8 +188,10 @@ class FileUtil(object):
                         self._chmod(dir_path + '/' + f_name,
                                     None, dirmode, mask)
             self._chmod(self.filename, filemode, dirmode, mask)
+
         except OSError:
             return False
+
         return True
 
     def rchmod(self, filemode=0o600, dirmode=0o700, mask=0o755):
@@ -180,25 +201,30 @@ class FileUtil(object):
     def _removedir(self):
         """Delete directory recursively"""
         try:
-            for dir_path, dirs, files in os.walk(self.filename, topdown=False,
-                                                 followlinks=False):
+            for dir_path, dirs, files in os.walk(self.filename, topdown=False, followlinks=False):
                 for f_name in files:
                     f_path = dir_path + '/' + f_name
                     if not os.path.islink(f_path):
                         os.chmod(f_path, stat.S_IWUSR | stat.S_IRUSR)
+
                     os.unlink(f_path)
+
                 for f_name in dirs:
                     f_path = dir_path + '/' + f_name
                     if os.path.islink(f_path):
                         os.unlink(f_path)
                         continue
+
                     os.chmod(f_path, stat.S_IWUSR | stat.S_IRUSR | stat.S_IXUSR)
                     os.rmdir(f_path)
+
             os.chmod(self.filename, stat.S_IWUSR | stat.S_IRUSR | stat.S_IXUSR)
             os.rmdir(self.filename)
+
         except OSError:
             Msg().err("Error: removing:", self.filename, l=Msg.VER)
             return False
+
         return True
 
     def remove(self, force=False, recursive=False):
@@ -212,8 +238,7 @@ class FileUtil(object):
             Msg().err("Error: delete not owner: ", self.filename)
             return False
         elif (not force) and (not self._is_safe_prefix(self.filename)):
-            Msg().err("Error: delete outside of directory tree: ",
-                      self.filename)
+            Msg().err("Error: delete outside of directory tree: ", self.filename)
             return False
         elif os.path.isfile(self.filename) or os.path.islink(self.filename):
             try:
@@ -226,11 +251,14 @@ class FileUtil(object):
                 status = self._removedir()
             else:
                 status = self.rmdir()
+
             if not status:
                 Msg().err("Error: deleting directory: ", self.filename)
                 return False
+
         if self.filename in dict(FileUtil.tmptrash):
             del FileUtil.tmptrash[self.filename]
+
         return True
 
     def verify_tar(self):
@@ -240,40 +268,47 @@ class FileUtil(object):
         verbose = ''
         if Msg.level >= Msg.VER:
             verbose = 'v'
+
         cmd = ["tar", "t" + verbose + "f", self.filename]
         if Uprocess().call(cmd, stderr=Msg.chlderr, stdout=Msg.chlderr,
                            close_fds=True):
             return False
+
         return True
 
     def tar(self, tarfile, sourcedir=None):
         """Create a tar file for a given sourcedir"""
-        #cmd += r" --xform 's:^\./::' "
         if sourcedir is None:
             sourcedir = self.filename
+
         verbose = ''
         if Msg.level >= Msg.VER:
             verbose = 'v'
+
         cmd = ["tar", "-C", sourcedir, "-c" + verbose, "--one-file-system",
                "-S", "--xattrs", "-f", tarfile, "."]
         status = Uprocess().call(cmd, stderr=Msg.chlderr, close_fds=True)
         if status:
             Msg().err("Error: creating tar file:", tarfile)
+
         return not status
 
     def copydir(self, destdir, sourcedir=None):
         """Copy directories"""
         if sourcedir is None:
             sourcedir = self.filename
+
         verbose = ''
         if Msg.level >= Msg.VER:
             verbose = 'v'
+
         cmd_tarc = ["tar", "-C", sourcedir, "-c" + verbose,
                     "--one-file-system", "-S", "--xattrs", "-f", "-", "."]
         cmd_tarx = ["tar", "-C", destdir, "-x" + verbose, "-f", "-"]
         status = Uprocess().pipe(cmd_tarc, cmd_tarx)
         if not status:
             Msg().err("Error: copying:", sourcedir, " to ", destdir, l=Msg.VER)
+
         return status
 
     def cleanup(self):
@@ -289,6 +324,7 @@ class FileUtil(object):
                 return True
         except (IOError, OSError, TypeError):
             pass
+
         return False
 
     def size(self):
@@ -304,7 +340,7 @@ class FileUtil(object):
         try:
             with open(self.filename, mode) as filep:
                 buf = filep.read()
-            Msg().out("Info: read buf", buf, l=Msg.DBG)
+            Msg().out("Debug: read buf", buf, l=Msg.DBG)
             return buf
         except (IOError, OSError, TypeError):
             return ""
@@ -335,7 +371,9 @@ class FileUtil(object):
         while f_path:
             if os.path.exists(f_path):
                 return f_path
+
             (f_path, dummy) = os.path.split(f_path)
+
         return f_path
 
     def _cont2host(self, pathname, container_root, volumes=""):
@@ -356,15 +394,17 @@ class FileUtil(object):
             elif pathname.startswith(host_path):
                 path = pathname
                 break
+
         if not path:
             path = real_container_root + '/' + pathname
+
         f_path = ""
         for d_comp in path.split('/')[1:]:
             f_path = f_path + '/' + d_comp
             while os.path.islink(f_path):
                 real_path = os.readlink(f_path)
                 if real_path.startswith('/'):
-                    if f_path.startswith(real_container_root): # in container
+                    if f_path.startswith(real_container_root):  # in container
                         if real_path.startswith(real_container_root):
                             f_path = real_path
                         else:
@@ -373,6 +413,7 @@ class FileUtil(object):
                         f_path = real_path
                 else:
                     f_path = os.path.dirname(f_path) + '/' + real_path
+
         return os.path.realpath(f_path)
 
     def cont2host(self, container_path, volumes=""):
@@ -385,19 +426,24 @@ class FileUtil(object):
         for directory in path:
             if not directory:
                 continue
+
             if directory == "." and workdir:
                 directory = workdir
             elif directory == ".." and workdir:
                 directory = workdir + "/.."
+
             if self.orig_filename.startswith("/"):
                 exec_path = self.orig_filename
             else:
                 exec_path = directory + "/" + self.orig_filename
+
             host_path = exec_path
             if rootdir:
                 host_path = self._cont2host(exec_path, rootdir, volumes)
+
             if os.path.isfile(host_path) and os.access(host_path, os.X_OK):
                 return host_path if cont2host else exec_path
+
         return ""
 
     def find_exec(self, path="", rootdir="", volumes="", workdir="",
@@ -405,14 +451,19 @@ class FileUtil(object):
         """Find an executable pathname"""
         if not path:
             path = os.getenv("PATH") + ":" + Config.conf['root_path']
+
         if rootdir:
             rootdir += "/"
+
         if is_genstr(path):
             if "=" in path:
                 path = "".join(path.split("=", 1)[1:])
+
             path = path.split(":")
+
         if not isinstance(path, (list, tuple)):
             return ""
+
         return self._find_exec(path, rootdir, volumes, workdir, cont2host)
 
     def rename(self, dest_filename):
@@ -421,6 +472,7 @@ class FileUtil(object):
             os.rename(self.filename, dest_filename)
         except (IOError, OSError):
             return False
+
         return True
 
     def _stream2file(self, dest_filename, mode="w"):
@@ -431,11 +483,18 @@ class FileUtil(object):
             fpdst = open(dest_filename, mode + "b")
         except (IOError, OSError):
             return False
+
         while True:
-            copy_buffer = sys.stdin.read(1024 * 1024)
+            if sys.version_info[0] >= 3:
+                copy_buffer = sys.stdin.buffer.read(1024 * 1024)
+            else:
+                copy_buffer = sys.stdin.read(1024 * 1024)
+
             if not copy_buffer:
                 break
+
             fpdst.write(copy_buffer)
+
         fpdst.close()
         return True
 
@@ -452,7 +511,11 @@ class FileUtil(object):
             copy_buffer = fpsrc.read(1024 * 1024)
             if not copy_buffer:
                 break
-            sys.stdout.write(copy_buffer)
+
+            if sys.version_info[0] >= 3:
+                sys.stdout.buffer.write(copy_buffer)
+            else:
+                sys.stdout.write(copy_buffer)
 
         fpsrc.close()
         return True
@@ -465,16 +528,19 @@ class FileUtil(object):
             fpsrc = open(self.filename, "rb")
         except (IOError, OSError):
             return False
+
         try:
             fpdst = open(dest_filename, mode + "b")
         except (IOError, OSError):
             fpsrc.close()
             return False
+
         while True:
             copy_buffer = fpsrc.read(1024 * 1024)
             if not copy_buffer:
                 break
             fpdst.write(copy_buffer)
+
         fpsrc.close()
         fpdst.close()
         return True
@@ -501,18 +567,17 @@ class FileUtil(object):
             image_path = path_prefix + "/" + image
             if os.path.exists(image_path):
                 return image_path
+
         return ""
 
     def _link_change_apply(self, new_l_path, f_path, force):
         """Actually apply the link convertion"""
         p_path = os.path.realpath(os.path.dirname(f_path))
         if force and not os.access(p_path, os.W_OK):
-            os.chmod(p_path,
-                     stat.S_IMODE(os.stat(p_path).st_mode) | stat.S_IWUSR)
+            os.chmod(p_path, stat.S_IMODE(os.stat(p_path).st_mode) | stat.S_IWUSR)
             os.remove(f_path)
             os.symlink(new_l_path, f_path)
-            os.chmod(p_path,
-                     stat.S_IMODE(os.stat(p_path).st_mode) & ~stat.S_IWUSR)
+            os.chmod(p_path, stat.S_IMODE(os.stat(p_path).st_mode) & ~stat.S_IWUSR)
         else:
             os.remove(f_path)
             os.symlink(new_l_path, f_path)
@@ -522,6 +587,7 @@ class FileUtil(object):
         l_path = os.readlink(f_path)
         if not l_path.startswith("/"):
             return False
+
         new_l_path = ""
         regexp_id = "[a-z0-9]+-[a-z0-9]+-[a-z0-9]+-[a-z0-9]+-[a-z0-9]+"
         recomp = re.compile("(/.*/containers/" + regexp_id + "/ROOT)(/.*)")
@@ -529,14 +595,16 @@ class FileUtil(object):
             match = recomp.match(l_path)
             if match:
                 orig_path = match.group(1)
-        if (orig_path and l_path.startswith(orig_path) and
-                orig_path != root_path):
+
+        if orig_path and l_path.startswith(orig_path) and orig_path != root_path:
             new_l_path = l_path.replace(orig_path, root_path, 1)
         elif not l_path.startswith(root_path):
             new_l_path = root_path + l_path
+
         if new_l_path:
             self._link_change_apply(new_l_path, f_path, force)
             return True
+
         return False
 
     def _link_restore(self, f_path, orig_path, root_path, force):
@@ -545,6 +613,7 @@ class FileUtil(object):
         new_l_path = ""
         if not l_path.startswith("/"):
             return False
+
         regexp_id = "[a-z0-9]+-[a-z0-9]+-[a-z0-9]+-[a-z0-9]+-[a-z0-9]+"
         recomp = re.compile("(/.*/containers/" + regexp_id + "/ROOT)(/.*)")
         if orig_path and l_path.startswith(orig_path):
@@ -555,9 +624,11 @@ class FileUtil(object):
             match = recomp.match(l_path)
             if match:
                 new_l_path = l_path.replace(match.group(1), "", 1)
+
         if new_l_path:
             self._link_change_apply(new_l_path, f_path, force)
             return True
+
         return False
 
     def links_conv(self, force=False, to_container=True, orig_path=""):
@@ -567,24 +638,28 @@ class FileUtil(object):
         if not self._is_safe_prefix(root_path):
             Msg().err("Error: links convertion outside of directory tree: ",
                       root_path)
+
             return None
+
         for dir_path, dirs, files in os.walk(root_path):
             for f_name in files + dirs:
                 try:
                     f_path = dir_path + "/" + f_name
                     if not os.path.islink(f_path):
                         continue
+
                     if os.lstat(f_path).st_uid != HostInfo.uid:
                         continue
+
                     if to_container:
                         if self._link_set(f_path, orig_path, root_path, force):
                             links.append(f_path)
-                    else:
-                        if self._link_restore(f_path, orig_path,
-                                              root_path, force):
-                            links.append(f_path)
+                    elif self._link_restore(f_path, orig_path, root_path, force):
+                        links.append(f_path)
+
                 except OSError:
                     continue
+
         return links
 
     def match(self):
@@ -594,7 +669,9 @@ class FileUtil(object):
         matching_files = []
         if not os.path.isdir(directory):
             return []
+
         for f_name in os.listdir(directory):
             if re.match(matching_expression, f_name):
                 matching_files.append(directory + "/" + f_name)
+
         return matching_files
